@@ -8,8 +8,8 @@ size=etape_inter[[1]];tagged=etape_inter[[3]];central=etape_inter[[5]];no_path=e
 
 test_that("interactions are well extracted", {
 #  expect_equal(nrow(size),282)
-#  expect_equal(nrow(tagged),11)
+  expect_equal(nrow(tagged),11)
 #  expect_equal(length(central),135)
-#  expect_equal(nrow(no_path),1)
+  expect_equal(nrow(no_path),1)
 })
 
