@@ -5,5 +5,5 @@ resmeta=listk[[1]];resgene=listk[[2]]
 
 test_that("pathways are found", {
   #expect_equal(nrow(resmeta),7)
-  #expect_equal(nrow(resgene),11)
+  expect_equal(nrow(resgene),11)
 })
